@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
-# Author: sorin sbarnea
-# License: public domain
 
-from tendo import colorer
+from tendo import colorer   # noqa
 
 if __name__ == '__main__':
     import logging
